@@ -7,9 +7,7 @@
 #include "kconstants.h"
 
 #include <QDesktopServices>
-#ifdef Q_OS_WIN
-#include <QtPlatformHeaders\QWindowsWindowFunctions>
-#endif
+
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
@@ -24,6 +22,9 @@ MainWindow::MainWindow(QWidget *parent) :
     mp_ui->tabBar->setStackedWidget(mp_ui->mainView);
 
     auto app = KiwixApp::instance();
+    addAction(app->getAction(KiwixApp::ToggleFullscreenAction));
+    addAction(app->getAction(KiwixApp::NextTabAction));
+    addAction(app->getAction(KiwixApp::PreviousTabAction));
 
     connect(app->getAction(KiwixApp::ExitAction), &QAction::triggered,
             this, &QMainWindow::close);
@@ -38,7 +39,7 @@ MainWindow::MainWindow(QWidget *parent) :
     connect(app->getAction(KiwixApp::KiwixServeAction), &QAction::triggered,
             mp_localKiwixServer, &QDialog::show);
 
-    connect(app, &KiwixApp::currentTitleChanged, this, [=](const QString& title) {
+    connect(mp_ui->tabBar, &TabBar::currentTitleChanged, this, [=](const QString& title) {
         if (!title.isEmpty() && !title.startsWith("zim://"))
             setWindowTitle(title + " - Kiwix");
         else
@@ -51,19 +52,22 @@ MainWindow::MainWindow(QWidget *parent) :
     setWindowFlags(Qt::Window | Qt::CustomizeWindowHint);
 #endif
 
-#ifdef Q_OS_WIN
-    QWindow *window = windowHandle();
-    if (!window) {
-        return;
-    }
-    QWindowsWindowFunctions::setHasBorderInFullScreen(window, true);
-#endif
-
     connect(mp_ui->tabBar, &QTabBar::currentChanged,
             mp_ui->mainToolBar, &TopWidget::updateBackForwardButtons);
     connect(mp_ui->tabBar, &TabBar::libraryPageDisplayed,
             this, &MainWindow::when_libraryPageDisplayed);
 
+    connect(mp_ui->tabBar, &TabBar::currentTitleChanged,
+            &(mp_ui->mainToolBar->getSearchBar()), &SearchBar::on_currentTitleChanged);
+
+    // This signal emited more often than the history really updated
+    // but for now we have no better signal for it.
+    connect(mp_ui->tabBar, &TabBar::currentTitleChanged,
+            mp_ui->mainToolBar, &TopWidget::updateBackForwardButtons);
+
+    connect(mp_ui->tabBar, &TabBar::webActionEnabledChanged,
+            mp_ui->mainToolBar, &TopWidget::handleWebActionEnabledChanged);
+
     mp_ui->contentmanagerside->setContentManager(app->getContentManager());
     mp_ui->sideBar->setCurrentWidget(mp_ui->contentmanagerside);
 }
@@ -74,12 +78,46 @@ MainWindow::~MainWindow()
 }
 
 void MainWindow::toggleFullScreen() {
-    if (isFullScreen())
+    if (isFullScreen()) {
+        QApplication::instance()->removeEventFilter(this);
+        showTabAndTop();
         showNormal();
-    else
+    }
+    else {
+        QApplication::instance()->installEventFilter(this);
+        hideTabAndTop();
         showFullScreen();
+    }
 }
 
+void MainWindow::hideTabAndTop() {
+    getTabBar()->hide();
+    getTopWidget()->hide();
+}
+
+void MainWindow::showTabAndTop() {
+    getTabBar()->show();
+    getTopWidget()->show();
+}
+
+bool MainWindow::eventFilter(QObject* /*object*/, QEvent* event)
+{
+    if (event->type() == QEvent::MouseMove && isFullScreen())
+    {
+        const auto mouseEvent = static_cast<QMouseEvent*>(event);
+        const int tabRegion = getTabBar()->height() + getTopWidget()->height() + 30;
+        // We don't have to check for visibilty as calling hide() on a hidden widget, or show() on a non-hidden widget is a no-op
+        if (mouseEvent->y() == 0) {
+            showTabAndTop();
+        } else if(mouseEvent->y() >= tabRegion) {
+            hideTabAndTop();
+        }
+        return true;
+    }
+    return false;
+}
+
+
 void MainWindow::when_ReadingList_toggled(bool state)
 {
     if (state) {
